@@ -158,6 +158,7 @@ def prepare_memtier_benchmark_parameters(
     tls_cert=None,
     tls_key=None,
     tls_cacert=None,
+    password=None,
 ):
     benchmark_command = [
         full_benchmark_path,
@@ -168,6 +169,8 @@ def prepare_memtier_benchmark_parameters(
         "--json-out-file",
         local_benchmark_output_filename,
     ]
+    if password is not None:
+        benchmark_command.extend(["-a", password])
     if tls_enabled:
         benchmark_command.append("--tls")
         if tls_cert is not None and tls_cert != "":
@@ -243,6 +246,7 @@ def process_self_contained_coordinator_stream(
 
                     port = args.db_server_port
                     host = args.db_server_host
+                    password = args.db_server_pass
 
                     ssl_cert_reqs = "required"
                     if tls_skip_verify:
@@ -250,6 +254,7 @@ def process_self_contained_coordinator_stream(
                     r = redis.StrictRedis(
                         host=host,
                         port=port,
+                        password=password,
                         ssl=tls_enabled,
                         ssl_cert_reqs=ssl_cert_reqs,
                         ssl_keyfile=tls_key,
@@ -304,6 +309,7 @@ def process_self_contained_coordinator_stream(
                             test_tls_cert,
                             test_tls_key,
                             test_tls_cacert,
+                            password,
                         )
 
                     execute_init_commands(
@@ -364,6 +370,7 @@ def process_self_contained_coordinator_stream(
                             test_tls_cert,
                             test_tls_key,
                             test_tls_cacert,
+                            password,
                         )
 
                     client_container_image = extract_client_container_image(
