@@ -52,6 +52,13 @@ def create_self_contained_coordinator_args(project_name):
         type=str,
         default=">",
     )
+    parser.add_argument(
+        "--consumer-id",
+        type=int,
+        default=1,
+        help="Consumer id for consumer group for platform",
+    )
+
     parser.add_argument(
         "--setups-folder",
         type=str,
